@@ -375,7 +375,7 @@ def BBHP(filepath,param,train_img_count=-1,test_img_count=-1,want_train=None, wa
             for key in results:
                 results[key] = round(results[key],round_out )
         
-            print(results)
+            #print(results)
 
 
             # save results
